@@ -2,6 +2,7 @@
 
 MAX_N_COLOR_BARS = 10
 
+from typing import Optional
 import warnings
 import os
 import appdirs
@@ -20,6 +21,8 @@ from pyvista.themes import DefaultTheme as _GlobalTheme  # hide this
 # Per contract with Sphinx-Gallery, this method must be available at top level
 from pyvista.utilities.sphinx_gallery import _get_sg_image_scraper
 
+from pyvista.utilities.wrappers import _wrappers
+
 global_theme = _GlobalTheme()
 rcParams = _rcParams()  # raises DeprecationError when used
 
@@ -45,6 +48,15 @@ try:
 except KeyError:
     pass
 
+# If available, a local vtk-data instance will be used for examples
+VTK_DATA_PATH: Optional[str] = None
+if 'PYVISTA_VTK_DATA' in os.environ:
+    VTK_DATA_PATH = os.environ['PYVISTA_VTK_DATA']
+    if not os.path.isdir(VTK_DATA_PATH):
+        warnings.warn(f"VTK_DATA_PATH: {VTK_DATA_PATH} is an invalid path")
+    if not os.path.isdir(os.path.join(VTK_DATA_PATH, 'Data')):
+        warnings.warn(f"VTK_DATA_PATH: {os.path.join(VTK_DATA_PATH, 'Data')} does not exist")
+
 # flag for when building the sphinx_gallery
 BUILDING_GALLERY = False
 if 'PYVISTA_BUILDING_GALLERY' in os.environ:
@@ -58,7 +70,6 @@ REPR_VOLUME_MAX_CELLS = 1e6
 FIGURE_PATH = None
 
 
-
 # allow user to override the examples path
 if 'PYVISTA_USERDATA_PATH' in os.environ:
     USER_DATA_PATH = os.environ['PYVISTA_USERDATA_PATH']
