@@ -149,7 +149,14 @@ class _ThemeConfig():
         return inst
 
     def to_dict(self) -> dict:
-        """Return theme config parameters as a dictionary."""
+        """Return theme config parameters as a dictionary.
+
+        Returns
+        -------
+        dict
+            This theme parameter represented as a dictionary.
+
+        """
         # remove the first underscore in each entry
         dict_ = {}
         for key in self.__slots__:
@@ -1140,7 +1147,11 @@ class DefaultTheme(_ThemeConfig):
                  '_smooth_shading',
                  '_depth_peeling',
                  '_silhouette',
-                 '_slider_styles']
+                 '_slider_styles',
+                 '_return_cpos',
+                 '_hidden_line_removal',
+                 '_antialiasing',
+    ]
 
     def __init__(self):
         """Initialize the theme."""
@@ -1201,6 +1212,52 @@ class DefaultTheme(_ThemeConfig):
         self._depth_peeling = _DepthPeelingConfig()
         self._silhouette = _SilhouetteConfig()
         self._slider_styles = _SliderConfig()
+        self._return_cpos = True
+        self._hidden_line_removal = False
+        self._antialiasing = False
+
+    @property
+    def hidden_line_removal(self) -> bool:
+        """Return or set hidden line removal.
+
+        Wireframe geometry will be drawn using hidden line removal if
+        the rendering engine supports it.
+
+        See Also
+        --------
+        pyvista.BasePlotter.enable_hidden_line_removal
+
+        Examples
+        --------
+        Enable hidden line removal.
+
+        >>> import pyvista
+        >>> pyvista.global_theme.hidden_line_removal = True
+        >>> pyvista.global_theme.hidden_line_removal
+        True
+
+        """
+        return self._hidden_line_removal
+
+    @hidden_line_removal.setter
+    def hidden_line_removal(self, value: bool):
+        self._hidden_line_removal = value
+
+    @property
+    def return_cpos(self) -> bool:
+        """Return or set the default behavior of returning the camera position.
+
+        Examples
+        --------
+        Disable returning camera position by ``show`` and `plot`` methods.
+
+        >>> import pyvista
+        >>> pyvista.global_theme.return_cpos = False
+        """
+
+    @return_cpos.setter
+    def return_cpos(self, value: bool):
+        self._return_cpos = value
 
     @property
     def background(self):
@@ -1244,6 +1301,12 @@ class DefaultTheme(_ThemeConfig):
           this is the only method that does not require a virtual
           framebuffer.  Must have ``ipygany`` installed.
 
+        * ``'pythreejs'`` : Convert all the meshes into ``pythreejs``
+          meshes and streams those to be rendered on the client side.
+          Aside from ``ipygany``, this is the only method that does
+          not require a virtual framebuffer.  Must have ``pythreejs``
+          installed.
+
         * ``'static'`` : Display a single static image within the
           JupyterLab environment.  Still requires that a virtual
           framebuffer be setup when displaying on a headless server,
@@ -1256,22 +1319,27 @@ class DefaultTheme(_ThemeConfig):
 
         Examples
         --------
+        Enable the pythreejs backend.
+
+        >>> import pyvista as pv
+        >>> pv.set_jupyter_backend('pythreejs')  # doctest:+SKIP
+
         Enable the ipygany backend.
 
         >>> import pyvista as pv
-        >>> pv.set_jupyter_backend('ipygany')
+        >>> pv.set_jupyter_backend('ipygany')  # doctest:+SKIP
 
         Enable the panel backend.
 
-        >>> pv.set_jupyter_backend('panel')
+        >>> pv.set_jupyter_backend('panel')  # doctest:+SKIP
 
         Enable the ipyvtklink backend.
 
-        >>> pv.set_jupyter_backend('ipyvtklink')
+        >>> pv.set_jupyter_backend('ipyvtklink')  # doctest:+SKIP
 
         Just show static images.
 
-        >>> pv.set_jupyter_backend('static')
+        >>> pv.set_jupyter_backend('static')  # doctest:+SKIP
 
         Disable all plotting within JupyterLab and display using a
         standard desktop VTK render window.
@@ -1765,11 +1833,31 @@ class DefaultTheme(_ThemeConfig):
     def title(self, title: str):
         self._title = title
 
+    @property
+    def antialiasing(self) -> bool:
+        """Enable or disable anti-aliasing.
+
+        Examples
+        --------
+        Enable anti-aliasing in the global theme.
+
+        >>> import pyvista
+        >>> pyvista.global_theme.antialiasing = True
+        >>> pyvista.global_theme.antialiasing
+        True
+
+        """
+        return self._antialiasing
+
+    @antialiasing.setter
+    def antialiasing(self, antialiasing: bool):
+        self._antialiasing = antialiasing
+
     @property
     def multi_samples(self) -> int:
         """Return or set the default ``multi_samples`` parameter.
 
-        Set the number of multisamples to enable hardware antialiasing.
+        Set the number of multisamples to used with hardware antialiasing.
 
         Examples
         --------
@@ -1985,6 +2073,9 @@ class DefaultTheme(_ThemeConfig):
             'Depth peeling': 'depth_peeling',
             'Silhouette': 'silhouette',
             'Slider Styles': 'slider_styles',
+            'Return Camera Position': 'return_cpos',
+            'Hidden Line Removal': 'hidden_line_removal',
+            'Anti-Aliasing': '_antialiasing',
         }
         for name, attr in parm.items():
             setting = getattr(self, attr)
@@ -2004,6 +2095,11 @@ class DefaultTheme(_ThemeConfig):
     def load_theme(self, theme):
         """Overwrite the current theme with a theme.
 
+        Parameters
+        ----------
+        theme : pyvista.DefaultTheme
+            Theme to use to overwrite this theme.
+
         Examples
         --------
         Create a custom theme from the default theme and load it into
@@ -2044,6 +2140,11 @@ class DefaultTheme(_ThemeConfig):
     def save(self, filename):
         """Serialize this theme to a json file.
 
+        Parameters
+        ----------
+        filename : str
+            Path to save the theme to.  Should end in ``'.json'``.
+
         Examples
         --------
         Export and then load back in a theme.
@@ -2152,9 +2253,15 @@ class ParaViewTheme(DefaultTheme):
 class DocumentTheme(DefaultTheme):
     """A document theme well suited for papers and presentations.
 
-    This theme uses a white background, black fonts, the "viridis"
-    colormap, and it disables edges.  Best used for presentations,
-    papers, etc.
+    This theme uses:
+
+    * A white background
+    * Black fonts
+    * The "viridis" colormap
+    * disables edges for surface plots
+    * Hidden edge removal
+
+    Best used for presentations, papers, etc.
 
     Examples
     --------
@@ -2187,6 +2294,7 @@ class DocumentTheme(DefaultTheme):
         self.axes.x_color = 'tomato'
         self.axes.y_color = 'seagreen'
         self.axes.z_color = 'blue'
+        self.hidden_line_removal = True
 
 
 class _TestingTheme(DefaultTheme):
@@ -2195,6 +2303,10 @@ class _TestingTheme(DefaultTheme):
     Necessary for image regression.  Xvfb doesn't support
     multi-sampling, it's disabled for consistency between desktops and
     remote testing.
+
+    Also disables ``return_cpos`` to make it easier for us to write
+    examples without returning camera positions.
+
     """
 
     def __init__(self):
@@ -2203,6 +2315,7 @@ class _TestingTheme(DefaultTheme):
         self.multi_samples = 1
         self.window_size = [400, 400]
         self.axes.show = False
+        self.return_cpos = False
 
 
 class _ALLOWED_THEMES(Enum):
