@@ -9,6 +9,7 @@ import sys
 from threading import Thread
 import threading
 import traceback
+from typing import Optional
 
 import numpy as np
 
@@ -28,13 +29,19 @@ class FieldAssociation(enum.Enum):
 
 
 def get_vtk_type(typ):
-    """Look up the VTK type for a give python data type.
+    """Look up the VTK type for a given numpy data type.
 
     Corrects for string type mapping issues.
 
+    Parameters
+    ----------
+    typ : numpy.dtype
+        Numpy data type.
+
     Returns
     -------
-        int : the integer type id specified in vtkType.h
+    int
+        Integer type id specified in ``vtkType.h``
 
     """
     typ = _vtk.get_vtk_array_type(typ)
@@ -45,23 +52,65 @@ def get_vtk_type(typ):
 
 
 def vtk_bit_array_to_char(vtkarr_bint):
-    """Cast vtk bit array to a char array."""
+    """Cast vtk bit array to a char array.
+
+    Parameters
+    ----------
+    vtkarr_bint : vtk.vtkBitArray
+        VTK binary array.
+
+    Returns
+    -------
+    vtk.vtkCharArray
+        VTK char array.
+
+    Notes
+    -----
+    This performs a copy.
+
+    """
     vtkarr = _vtk.vtkCharArray()
     vtkarr.DeepCopy(vtkarr_bint)
     return vtkarr
 
 
 def vtk_id_list_to_array(vtk_id_list):
-    """Convert a vtkIdList to a NumPy array."""
+    """Convert a vtkIdList to a NumPy array.
+
+    Parameters
+    ----------
+    vtk_id_list : vtk.vtkIdList
+        VTK ID list.
+
+    Returns
+    -------
+    numpy.ndarray
+        Array of IDs.
+
+    """
     return np.array([vtk_id_list.GetId(i) for i in range(vtk_id_list.GetNumberOfIds())])
 
 
 def convert_string_array(arr, name=None):
     """Convert a numpy array of strings to a vtkStringArray or vice versa.
 
-    Note that this is terribly inefficient - inefficient support
-    is better than no support :). If you have ideas on how to make this faster,
-    please consider opening a pull request.
+    Parameters
+    ----------
+    arr : numpy.ndarray
+        Numpy string array to convert.
+
+    name : str, optional
+        Name to set the vtkStringArray to.
+
+    Returns
+    -------
+    vtkStringArray
+        VTK string array.
+
+    Notes
+    -----
+    Note that this is terribly inefficient. If you have ideas on how
+    to make this faster, please consider opening a pull request.
 
     """
     if isinstance(arr, np.ndarray):
@@ -80,25 +129,26 @@ def convert_string_array(arr, name=None):
     ########################################
 
 
-def convert_array(arr, name=None, deep=0, array_type=None):
+def convert_array(arr, name=None, deep=False, array_type=None):
     """Convert a NumPy array to a vtkDataArray or vice versa.
 
     Parameters
-    -----------
-    arr : ndarray or vtkDataArry
-        A numpy array or vtkDataArry to convert
-    name : str
-        The name of the data array for VTK
-    deep : bool
-        if input is numpy array then deep copy values
+    ----------
+    arr : np.ndarray or vtkDataArray
+        A numpy array or vtkDataArry to convert.
+    name : str, optional
+        The name of the data array for VTK.
+    deep : bool, optional
+        If input is numpy array then deep copy values.
+    array_type : int, optional
+        VTK array type ID as specified in specified in ``vtkType.h``.
 
     Returns
     -------
-    vtkDataArray, ndarray, or DataFrame:
-        the converted array (if input is a NumPy ndaray then returns
-        ``vtkDataArray`` or is input is ``vtkDataArray`` then returns NumPy
-        ``ndarray``). If pdf==True and the input is ``vtkDataArry``,
-        return a pandas DataFrame.
+    vtkDataArray, numpy.ndarray, or DataFrame
+        The converted array.  If input is a :class:`numpy.ndarray` then
+        returns ``vtkDataArray`` or is input is ``vtkDataArray`` then
+        returns NumPy ``ndarray``.
 
     """
     if arr is None:
@@ -132,36 +182,121 @@ def convert_array(arr, name=None, deep=0, array_type=None):
 
 
 def is_pyvista_dataset(obj):
-    """Return True if the Object is a PyVista wrapped dataset."""
+    """Return ``True`` if the object is a PyVista wrapped dataset.
+
+    Parameters
+    ----------
+    obj : anything
+        Any object to test.
+
+    Returns
+    -------
+    bool
+        ``True`` when the object is a :class:`pyvista.DataSet`.
+
+    """
     return isinstance(obj, (pyvista.DataSet, pyvista.MultiBlock))
 
 
-def point_array(mesh, name):
-    """Return point array of a vtk object."""
-    vtkarr = mesh.GetPointData().GetAbstractArray(name)
+def point_array(obj, name):
+    """Return point array of a pyvista or vtk object.
+
+    Parameters
+    ----------
+    obj : pyvista.DataSet or vtk.vtkDataSet
+        PyVista or VTK dataset.
+
+    name : str
+        Name of the array.
+
+    Returns
+    -------
+    numpy.ndarray
+        Wrapped array.
+
+    """
+    vtkarr = obj.GetPointData().GetAbstractArray(name)
     return convert_array(vtkarr)
 
 
-def field_array(mesh, name):
-    """Return field array of a vtk object."""
-    vtkarr = mesh.GetFieldData().GetAbstractArray(name)
+def field_array(obj, name):
+    """Return field data of a pyvista or vtk object.
+
+    Parameters
+    ----------
+    obj : pyvista.DataSet or vtk.vtkDataSet
+        PyVista or VTK dataset.
+
+    name : str
+        Name of the array.
+
+    Returns
+    -------
+    numpy.ndarray
+        Wrapped array.
+
+    """
+    vtkarr = obj.GetFieldData().GetAbstractArray(name)
     return convert_array(vtkarr)
 
 
-def cell_array(mesh, name):
-    """Return cell array of a vtk object."""
-    vtkarr = mesh.GetCellData().GetAbstractArray(name)
+def cell_array(obj, name):
+    """Return cell array of a pyvista or vtk object.
+
+    Parameters
+    ----------
+    obj : pyvista.DataSet or vtk.vtkDataSet
+        PyVista or VTK dataset.
+
+    name : str
+        Name of the array.
+
+    Returns
+    -------
+    numpy.ndarray
+        Wrapped array.
+
+    """
+    vtkarr = obj.GetCellData().GetAbstractArray(name)
     return convert_array(vtkarr)
 
 
-def row_array(data_object, name):
-    """Return row array of a vtk object."""
-    vtkarr = data_object.GetRowData().GetAbstractArray(name)
+def row_array(obj, name):
+    """Return row array of a vtk object.
+
+    Parameters
+    ----------
+    obj : vtk.vtkDataSet
+        PyVista or VTK dataset.
+
+    name : str
+        Name of the array.
+
+    Returns
+    -------
+    numpy.ndarray
+        Wrapped array.
+
+    """
+    vtkarr = obj.GetRowData().GetAbstractArray(name)
     return convert_array(vtkarr)
 
 
 def parse_field_choice(field):
-    """Return the id of the given field."""
+    """Return a field association object for a given field type string.
+
+    Parameters
+    ----------
+    field : str, FieldAssociation
+        Name of the field (e.g, ``'cell'``, ``'field'``, ``'point'``,
+        ``'row'``).
+
+    Returns
+    -------
+    pyvista.FieldAssociation
+        Field association.
+
+    """
     if isinstance(field, str):
         field = field.strip().lower()
         if field in ['cell', 'c', 'cells']:
@@ -181,77 +316,147 @@ def parse_field_choice(field):
     return field
 
 
-def get_array(mesh, name, preference='cell', info=False, err=False):
+def get_array(mesh, name, preference='cell', err=False) -> Optional[np.ndarray]:
     """Search point, cell and field data for an array.
 
     Parameters
     ----------
+    mesh : pyvista.DataSet
+        Dataset to get the array from.
+
     name : str
         The name of the array to get the range.
 
     preference : str, optional
         When scalars is specified, this is the preferred array type to
         search for in the dataset.  Must be either ``'point'``,
-        ``'cell'``, or ``'field'``
+        ``'cell'``, or ``'field'``.
 
-    info : bool
-        Return info about the array rather than the array itself.
+    err : bool, optional
+        Whether to throw an error if array is not present.
 
-    err : bool
-        Boolean to control whether to throw an error if array is not present.
+    Returns
+    -------
+    pyvista.pyvista_ndarray or ``None``
+        Requested array.  Return ``None`` if there is no array
+        matching the ``name`` and ``err=False``.
 
     """
     if isinstance(mesh, _vtk.vtkTable):
         arr = row_array(mesh, name)
         if arr is None and err:
             raise KeyError(f'Data array ({name}) not present in this dataset.')
-        field = FieldAssociation.ROW
-        if info:
-            return arr, field
         return arr
 
     parr = point_array(mesh, name)
     carr = cell_array(mesh, name)
     farr = field_array(mesh, name)
     preference = parse_field_choice(preference)
-    if np.sum([parr is not None, carr is not None, farr is not None]) > 1:
+    if sum([array is not None for array in (parr, carr, farr)]) > 1:
         if preference == FieldAssociation.CELL:
-            if info:
-                return carr, FieldAssociation.CELL
-            else:
-                return carr
+            return carr
         elif preference == FieldAssociation.POINT:
-            if info:
-                return parr, FieldAssociation.POINT
-            else:
-                return parr
+            return parr
         elif preference == FieldAssociation.NONE:
-            if info:
-                return farr, FieldAssociation.NONE
-            else:
-                return farr
+            return farr
         else:
             raise ValueError(f'Data field ({preference}) not supported.')
-    arr = None
-    field = None
+
     if parr is not None:
-        arr = parr
-        field = FieldAssociation.POINT
+        return parr
     elif carr is not None:
-        arr = carr
-        field = FieldAssociation.CELL
+        return carr
     elif farr is not None:
-        arr = farr
-        field = FieldAssociation.NONE
+        return farr
     elif err:
         raise KeyError(f'Data array ({name}) not present in this dataset.')
-    if info:
-        return arr, field
-    return arr
+    return None
+
+
+def get_array_association(mesh, name, preference='cell', err=False) -> FieldAssociation:
+    """Return the array association.
+
+    Parameters
+    ----------
+    mesh : Dataset
+        Dataset to get the array association from.
+
+    name : str
+        The name of the array.
+
+    preference : str, optional
+        When scalars is specified, this is the preferred array type to
+        search for in the dataset.  Must be either ``'point'``,
+        ``'cell'``, or ``'field'``.
+
+    err : bool, optional
+        Boolean to control whether to throw an error if array is not
+        present.
+
+    Returns
+    -------
+    pyvista.FieldAssociation
+        Association of the array. If array is not present and ``err`` is
+        ``False``, ``FieldAssociation.NONE`` is returned.
+
+    """
+    if isinstance(mesh, _vtk.vtkTable):
+        arr = row_array(mesh, name)
+        if arr is None and err:
+            raise KeyError(f'Data array ({name}) not present in this dataset.')
+        return FieldAssociation.ROW
+
+    # with multiple arrays, return the array preference if possible
+    parr = point_array(mesh, name)
+    carr = cell_array(mesh, name)
+    farr = field_array(mesh, name)
+    arrays = [parr, carr, farr]
+    preferences = [FieldAssociation.POINT, FieldAssociation.CELL, FieldAssociation.NONE]
+    preference = parse_field_choice(preference)
+    if preference not in preferences:
+        raise ValueError(f'Data field ({preference}) not supported.')
+
+    matches = [pref for pref, array in zip(preferences, arrays) if array is not None]
+    # optionally raise if no match
+    if not matches:
+        if err:
+            raise KeyError(f'Data array ({name}) not present in this dataset.')
+        return FieldAssociation.NONE
+    # use preference if it applies
+    if preference in matches:
+        return preference
+    # otherwise return first in order of point -> cell -> field
+    return matches[0]
 
 
 def vtk_points(points, deep=True):
-    """Convert numpy array or array-like to a vtkPoints object."""
+    """Convert numpy array or array-like to a ``vtkPoints`` object.
+
+    Parameters
+    ----------
+    points : numpy.ndarray or sequence
+        Points to convert.  Should be 1 or 2 dimensional.  Accepts a
+        single point or several points.
+
+    deep : bool, optional
+        Perform a deep copy of the array.  Only applicable if
+        ``points`` is a :class:`numpy.ndarray`.
+
+    Returns
+    -------
+    vtk.vtkPoints
+        The vtkPoints object.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> import numpy as np
+    >>> points = np.random.random((10, 3))
+    >>> vpoints = pyvista.vtk_points(points)
+    >>> vpoints  # doctest:+SKIP
+    (vtkmodules.vtkCommonCore.vtkPoints)0x7f0c2e26af40
+
+    """
     points = np.asanyarray(points)
 
     # verify is numeric
@@ -286,17 +491,15 @@ def line_segments_from_points(points):
 
     Parameters
     ----------
-    points : np.ndarray
+    points : numpy.ndarray
         Points representing line segments. An even number must be
         given as every two vertices represent a single line
         segment. For example, two line segments would be represented
-        as:
-
-        ``np.array([[0, 0, 0], [1, 0, 0], [1, 0, 0], [1, 1, 0]])``
+        as ``np.array([[0, 0, 0], [1, 0, 0], [1, 0, 0], [1, 1, 0]])``.
 
     Returns
     -------
-    lines : pyvista.PolyData
+    pyvista.PolyData
         PolyData with lines and cells.
 
     Examples
@@ -307,7 +510,7 @@ def line_segments_from_points(points):
     >>> import numpy as np
     >>> points = np.array([[0, 0, 0], [1, 0, 0], [1, 0, 0], [1, 1, 0]])
     >>> lines = pyvista.lines_from_points(points)
-    >>> cpos = lines.plot()
+    >>> lines.plot()
 
     """
     if len(points) % 2 != 0:
@@ -330,19 +533,26 @@ def lines_from_points(points, close=False):
     Parameters
     ----------
     points : np.ndarray
-        Points representing the vertices of the connected segments. For
-        example, two line segments would be represented as:
-
-        np.array([[0, 0, 0], [1, 0, 0], [1, 1, 0]])
+        Points representing the vertices of the connected
+        segments. For example, two line segments would be represented
+        as ``np.array([[0, 0, 0], [1, 0, 0], [1, 1, 0]])``.
 
     close : bool, optional
-        If True, close the line segments into a loop
+        If ``True``, close the line segments into a loop.
 
     Returns
     -------
-    lines : pyvista.PolyData
+    pyvista.PolyData
         PolyData with lines and cells.
 
+    Examples
+    --------
+    >>> import numpy as np
+    >>> import pyvista
+    >>> points = np.array([[0, 0, 0], [1, 0, 0], [1, 1, 0]])
+    >>> poly = pyvista.lines_from_points(points)
+    >>> poly.plot(line_width=5)
+
     """
     poly = pyvista.PolyData()
     poly.points = points
@@ -366,7 +576,7 @@ def make_tri_mesh(points, faces):
     Parameters
     ----------
     points : np.ndarray
-        Array of points with shape (N, 3) storing the vertices of the
+        Array of points with shape ``(N, 3)`` storing the vertices of the
         triangle mesh.
 
     faces : np.ndarray
@@ -375,7 +585,7 @@ def make_tri_mesh(points, faces):
 
     Returns
     -------
-    tri_mesh : pyvista.PolyData
+    pyvista.PolyData
         PolyData instance containing the triangle mesh.
 
     Examples
@@ -384,14 +594,14 @@ def make_tri_mesh(points, faces):
     nine vertices and eight faces.
 
     >>> import numpy as np
-    >>> import pyvista as pv
+    >>> import pyvista
     >>> points = np.array([[0, 0, 0], [0.5, 0, 0], [1, 0, 0], [0, 0.5, 0],
     ...                    [0.5, 0.5, 0], [1, 0.5, 0], [0, 1, 0], [0.5, 1, 0],
     ...                    [1, 1, 0]])
     >>> faces = np.array([[0, 1, 4], [4, 7, 6], [2, 5, 4], [4, 5, 8],
     ...                   [0, 4, 3], [3, 4, 6], [1, 2, 4], [4, 8, 7]])
     >>> tri_mesh = pyvista.make_tri_mesh(points, faces)
-    >>> cpos = tri_mesh.plot(show_edges=True)
+    >>> tri_mesh.plot(show_edges=True, line_width=5)
 
     """
     if points.shape[1] != 3:
@@ -405,7 +615,44 @@ def make_tri_mesh(points, faces):
 
 
 def vector_poly_data(orig, vec):
-    """Create a vtkPolyData object composed of vectors."""
+    """Create a pyvista.PolyData object composed of vectors.
+
+    Parameters
+    ----------
+    orig : numpy.ndarray
+        Array of vector origins.
+
+    vec : numpy.ndarray
+        Array of vectors.
+
+    Returns
+    -------
+    pyvista.PolyData
+        Mesh containing the ``orig`` points along with the
+        ``'vectors'`` and ``'mag'`` point arrays representing the
+        vectors and magnitude of the the vectors at each point.
+
+    Examples
+    --------
+    Create basic vector field.  This is a point cloud where each point
+    has a vector and magnitude attached to it.
+
+    >>> import pyvista
+    >>> import numpy as np
+    >>> x, y = np.meshgrid(np.linspace(-5,5,10),np.linspace(-5,5,10))
+    >>> points = np.vstack((x.ravel(), y.ravel(), np.zeros(x.size))).T
+    >>> u = x/np.sqrt(x**2 + y**2)
+    >>> v = y/np.sqrt(x**2 + y**2)
+    >>> vectors = np.vstack((u.ravel()**3, v.ravel()**3, np.zeros(u.size))).T
+    >>> pdata = pyvista.vector_poly_data(points, vectors)
+    >>> pdata.point_data.keys()
+    ['vectors', 'mag']
+
+    Convert these to arrows and plot it.
+
+    >>> pdata.glyph(orient='vectors', scale='mag').plot()
+
+    """
     # shape, dimension checking
     if not isinstance(orig, np.ndarray):
         orig = np.asarray(orig)
@@ -468,7 +715,7 @@ def trans_from_matrix(matrix):  # pragma: no cover
 
 
 def array_from_vtkmatrix(matrix):
-    """Convert a vtk matrix to a ``numpy.ndarray``.
+    """Convert a vtk matrix to an array.
 
     Parameters
     ----------
@@ -476,6 +723,11 @@ def array_from_vtkmatrix(matrix):
         The vtk matrix to be converted to a ``numpy.ndarray``.
         Returned ndarray has shape (3, 3) or (4, 4) as appropriate.
 
+    Returns
+    -------
+    numpy.ndarray
+        Numpy array containing the data from ``matrix``.
+
     """
     if isinstance(matrix, _vtk.vtkMatrix3x3):
         shape = (3, 3)
@@ -501,6 +753,11 @@ def vtkmatrix_from_array(array):
         Shape (3, 3) gets converted to a ``vtk.vtkMatrix3x3``, shape (4, 4)
         gets converted to a ``vtk.vtkMatrix4x4``. No other shapes are valid.
 
+    Returns
+    -------
+    vtk.vtkMatrix3x3 or vtk.vtkMatrix4x4
+        VTK matrix.
+
     """
     array = np.asarray(array)
     if array.shape == (3, 3):
@@ -516,23 +773,36 @@ def vtkmatrix_from_array(array):
     return matrix
 
 
-def is_meshio_mesh(mesh):
-    """Test if passed object is instance of ``meshio.Mesh``."""
+def is_meshio_mesh(obj):
+    """Test if passed object is instance of ``meshio.Mesh``.
+
+    Parameters
+    ----------
+    obj
+        Any object.
+
+    Returns
+    -------
+    bool
+        ``True`` if ``obj`` is an ``meshio.Mesh``.
+
+    """
     try:
         import meshio
-        return isinstance(mesh, meshio.Mesh)
+        return isinstance(obj, meshio.Mesh)
     except ImportError:
         return False
 
 
 def wrap(dataset):
-    """Wrap any given VTK data object to its appropriate pyvista data object.
+    """Wrap any given VTK data object to its appropriate PyVista data object.
 
     Other formats that are supported include:
+
     * 2D :class:`numpy.ndarray` of XYZ vertices
     * 3D :class:`numpy.ndarray` representing a volume. Values will be scalars.
     * 3D :class:`trimesh.Trimesh` mesh.
-    * 3D :class:`meshio` mesh.
+    * 3D :class:`meshio.Mesh` mesh.
 
     Parameters
     ----------
@@ -541,8 +811,8 @@ def wrap(dataset):
 
     Returns
     -------
-    wrapped_dataset : pyvista class
-        The `pyvista` wrapped dataset.
+    pyvista.DataSet
+        The PyVista wrapped dataset.
 
     Examples
     --------
@@ -622,24 +892,15 @@ def wrap(dataset):
         else:
             raise NotImplementedError('NumPy array could not be wrapped pyvista.')
 
-    wrappers = {
-        'vtkExplicitStructuredGrid': pyvista.ExplicitStructuredGrid,
-        'vtkUnstructuredGrid': pyvista.UnstructuredGrid,
-        'vtkRectilinearGrid': pyvista.RectilinearGrid,
-        'vtkStructuredGrid': pyvista.StructuredGrid,
-        'vtkPolyData': pyvista.PolyData,
-        'vtkImageData': pyvista.UniformGrid,
-        'vtkStructuredPoints': pyvista.UniformGrid,
-        'vtkMultiBlockDataSet': pyvista.MultiBlock,
-        'vtkTable': pyvista.Table,
-        # 'vtkParametricSpline': pyvista.Spline,
-    }
+    # wrap VTK arrays as pyvista_ndarray
+    if isinstance(dataset, _vtk.vtkDataArray):
+        return pyvista.pyvista_ndarray(dataset)
 
     # Check if a dataset is a VTK type
     if hasattr(dataset, 'GetClassName'):
         key = dataset.GetClassName()
         try:
-            return wrappers[key](dataset)
+            return pyvista._wrappers[key](dataset)
         except KeyError:
             logging.warning(f'VTK data type ({key}) is not currently supported by pyvista.')
         return
@@ -662,12 +923,36 @@ def wrap(dataset):
 
 
 def image_to_texture(image):
-    """Convert ``vtkImageData`` (:class:`pyvista.UniformGrid`) to a ``vtkTexture``."""
+    """Convert ``vtkImageData`` (:class:`pyvista.UniformGrid`) to a ``vtkTexture``.
+
+    Parameters
+    ----------
+    image : pyvista.UniformGrid or vtkImageData
+        Image to convert.
+
+    Returns
+    -------
+    vtkTexture
+        VTK texture.
+
+    """
     return pyvista.Texture(image)
 
 
 def numpy_to_texture(image):
-    """Convert a NumPy image array to a vtk.vtkTexture."""
+    """Convert a NumPy image array to a vtk.vtkTexture.
+
+    Parameters
+    ----------
+    image : numpy.ndarray
+        Numpy image array.
+
+    Returns
+    -------
+    vtkTexture
+        VTK texture.
+
+    """
     return pyvista.Texture(image)
 
 
@@ -676,6 +961,19 @@ def is_inside_bounds(point, bounds):
 
     This is implemented through recursion so that this is N-dimensional.
 
+    Parameters
+    ----------
+    point : sequence
+        Three item cartesian point (i.e. ``[x, y, z]``).
+
+    bounds : sequence
+        Six item bounds in the form of ``(xMin, xMax, yMin, yMax, zMin, zMax)``.
+
+    Returns
+    -------
+    bool
+        ``True`` when ``point`` is inside ``bounds``.
+
     """
     if isinstance(point, (int, float)):
         point = [point]
@@ -697,15 +995,45 @@ def is_inside_bounds(point, bounds):
 
 
 def fit_plane_to_points(points, return_meta=False):
-    """Fit a plane to a set of points.
+    """Fit a plane to a set of points using the SVD algorithm.
 
     Parameters
     ----------
-    points : np.ndarray
-        Size n by 3 array of points to fit a plane through
+    points : sequence
+        Size ``[N x 3]`` sequence of points to fit a plane through.
 
-    return_meta : bool
-        If true, also returns the center and normal used to generate the plane
+    return_meta : bool, optional
+        If ``True``, also returns the center and normal used to
+        generate the plane.
+
+    Returns
+    -------
+    pyvista.PolyData
+        Plane mesh.
+
+    numpy.ndarray
+        Plane center if ``return_meta=True``.
+
+    numpy.ndarray
+        Plane normal if ``return_meta=True``.
+
+    Examples
+    --------
+    Fit a plane to a random point cloud.
+
+    >>> import pyvista
+    >>> import numpy as np
+    >>> cloud = np.random.random((10, 3))
+    >>> cloud[:, 2] *= 0.1
+    >>> plane, center, normal = pyvista.fit_plane_to_points(cloud, return_meta=True)
+
+    Plot the fitted plane.
+
+    >>> pl = pyvista.Plotter()
+    >>> _ = pl.add_mesh(plane, color='tan', style='wireframe', line_width=4)
+    >>> _ = pl.add_points(cloud, render_points_as_spheres=True, 
+    ...                   color='r', point_size=30)
+    >>> pl.show()
 
     """
     data = np.array(points)
@@ -718,17 +1046,46 @@ def fit_plane_to_points(points, return_meta=False):
     return plane
 
 
-def raise_not_matching(scalars, mesh):
-    """Raise exception about inconsistencies."""
-    if isinstance(mesh, _vtk.vtkTable):
-        raise ValueError(f'Number of scalars ({scalars.size}) must match number of rows ({mesh.n_rows}).')
+def raise_not_matching(scalars, dataset):
+    """Raise exception about inconsistencies.
+
+    Parameters
+    ----------
+    scalars : numpy.ndarray
+        Array of scalars.
+
+    dataset : pyvista.DataSet
+        Dataset to check against.
+
+    Raises
+    ------
+    ValueError
+        Raises a ValueError if the size of scalars does not the dataset.
+    """
+    if isinstance(dataset, _vtk.vtkTable):
+        raise ValueError(f'Number of scalars ({scalars.size}) must match number of rows ({dataset.n_rows}).')
     raise ValueError(f'Number of scalars ({scalars.size}) '
-                     f'must match either the number of points ({mesh.n_points}) '
-                     f'or the number of cells ({mesh.n_cells}).')
+                     f'must match either the number of points ({dataset.n_points}) '
+                     f'or the number of cells ({dataset.n_cells}).')
 
 
 def generate_plane(normal, origin):
-    """Return a _vtk.vtkPlane."""
+    """Return a _vtk.vtkPlane.
+
+    Parameters
+    ----------
+    normal : sequence
+        Three item sequence representing the normal of the plane.
+
+    origin : sequence
+        Three item sequence representing the origin of the plane.
+
+    Returns
+    -------
+    vtk.vtkPlane
+        VTK plane.
+
+    """
     plane = _vtk.vtkPlane()
     # NORMAL MUST HAVE MAGNITUDE OF 1
     normal = normal / np.linalg.norm(normal)
@@ -738,7 +1095,17 @@ def generate_plane(normal, origin):
 
 
 def try_callback(func, *args):
-    """Wrap a given callback in a try statement."""
+    """Wrap a given callback in a try statement.
+
+    Parameters
+    ----------
+    func : callable
+        Callable object.
+
+    *args
+        Any arguments.
+
+    """
     try:
         func(*args)
     except Exception:
@@ -749,7 +1116,6 @@ def try_callback(func, *args):
             ''.join(traceback.format_list(stack) +
                     traceback.format_exception_only(etype, exc)).rstrip('\n')
         logging.warning(formatted_exception)
-    return
 
 
 def check_depth_peeling(number_of_peels=100, occlusion_ratio=0.0):
@@ -760,6 +1126,20 @@ def check_depth_peeling(number_of_peels=100, occlusion_ratio=0.0):
     available and has been successfully leveraged, otherwise
     ``False``.
 
+    Parameters
+    ----------
+    number_of_peels : int, optional
+        Maximum number of depth peels.
+
+    occlusion_ratio : float, optional
+        Occlusion ratio.
+
+    Returns
+    -------
+    bool
+        ``True`` when system supports depth peeling with the specified
+        settings.
+
     """
     # Try Depth Peeling with a basic scene
     source = _vtk.vtkSphereSource()
@@ -784,7 +1164,19 @@ def check_depth_peeling(number_of_peels=100, occlusion_ratio=0.0):
 
 
 def threaded(fn):
-    """Call a function using a thread."""
+    """Call a function using a thread.
+
+    Parameters
+    ----------
+    fn : callable
+        Callable object.
+
+    Returns
+    -------
+    function
+        Wrapped function.
+
+    """
 
     def wrapper(*args, **kwargs):
         thread = Thread(target=fn, args=args, kwargs=kwargs)
@@ -795,7 +1187,16 @@ def threaded(fn):
 
 
 class conditional_decorator:
-    """Conditional decorator for methods."""
+    """Conditional decorator for methods.
+
+    Parameters
+    ----------
+    dec
+        Decorator
+    condition
+        Condition to match.
+
+    """
 
     def __init__(self, dec, condition):
         """Initialize."""
@@ -817,6 +1218,17 @@ class ProgressMonitor():
     interrupts from happening until the exit event as interrupts will crash
     the kernel if the VTK algorithm is still executing.
 
+    Parameters
+    ----------
+    algorithm
+        VTK algorithm or filter.
+
+    message : str, optional
+        Message to display in the progress bar.
+
+    scaling : float, optional
+        Unused keyword argument.
+
     """
 
     def __init__(self, algorithm, message="", scaling=100):
@@ -916,7 +1328,7 @@ def axis_rotation(points, angle, inplace=False, deg=True, axis='z'):
 
     Returns
     -------
-    points : numpy.ndarray
+    numpy.ndarray
         Rotated points.
 
     Examples
@@ -971,15 +1383,15 @@ def cubemap(path='', prefix='', ext='.jpg'):
 
     Parameters
     ----------
+    path : str, optional
+        Directory containing the cubemap images.
+
     prefix : str, optional
         Prefix to the filename.
 
     ext : str, optional
         The filename extension.  For example ``'.jpg'``.
 
-    path : str, optional
-        Directory containing the cubemap images.
-
     Returns
     -------
     pyvista.Texture
@@ -1001,6 +1413,8 @@ def cubemap(path='', prefix='', ext='.jpg'):
                                     f'{file_str}')
 
     texture = pyvista.Texture()
+    texture.SetMipmap(True)
+    texture.SetInterpolate(True)
     texture.cube_map = True  # Must be set prior to setting images
 
     # add each image to the cubemap
